pub enum PlayerHubMethod {
Show 16 variants
Play {
id: u64,
quality: Option<String>,
},
Pause,
Resume,
Stop,
Next,
Previous,
Volume {
level: f32,
},
Preamp {
level: f32,
},
QueueAlbum {
id: u64,
quality: Option<String>,
},
QueueAdd {
id: u64,
quality: Option<String>,
},
QueueBatch {
ids: Vec<u64>,
quality: Option<String>,
},
QueueClear,
QueueGet,
QueueReorder {
from: u32,
to: u32,
},
Status,
NowPlaying,
}Expand description
Auto-generated method enum for schema extraction
Variants
Play
Play a track immediately (stops current playback)
Pause
Pause playback
Resume
Resume playback
Stop
Stop playback
Next
Skip to next track in queue
Previous
Go to previous track
Volume
Set volume level
Preamp
Set pre-amp gain level
QueueAlbum
Add an entire album to the playback queue
QueueAdd
Add a track to the playback queue
QueueBatch
Add multiple tracks to the queue at once
QueueClear
Clear the playback queue
QueueGet
List queue contents
QueueReorder
Reorder tracks in the queue
Status
Get current playback status (single snapshot, returns immediately)
NowPlaying
Stream now-playing updates (~1s while playing)
Implementations
Sourceimpl PlayerHubMethod
impl PlayerHubMethod
pub fn all_method_names() -> &'static [&'static str]
Sourceimpl PlayerHubMethod
impl PlayerHubMethod
Sourcepub fn method_schemas() -> Vec<MethodSchema>
pub fn method_schemas() -> Vec<MethodSchema>
Get per-method schema info including params, return types, and content hashes
Note: This method has O(1) schema lookup cost after first call due to caching.