pub struct MonoHub { /* private fields */ }Expand description
Monochrome music API activation — stateless API proxy.
Implementations
Sourceimpl MonoHub
impl MonoHub
Sourceimpl MonoHub
impl MonoHub
Sourcepub async fn track(
&self,
id: u64,
) -> impl Stream<Item = MonoEvent> + Send + 'static
pub async fn track( &self, id: u64, ) -> impl Stream<Item = MonoEvent> + Send + 'static
Get track metadata by Tidal track ID
Sourcepub async fn album(
&self,
id: u64,
) -> impl Stream<Item = MonoEvent> + Send + 'static
pub async fn album( &self, id: u64, ) -> impl Stream<Item = MonoEvent> + Send + 'static
Get album metadata and its full track listing by Tidal album ID
Sourcepub async fn artist(
&self,
id: u64,
) -> impl Stream<Item = MonoEvent> + Send + 'static
pub async fn artist( &self, id: u64, ) -> impl Stream<Item = MonoEvent> + Send + 'static
Get artist metadata by Tidal artist ID
Sourcepub async fn search(
&self,
query: String,
kind: Option<SearchKind>,
limit: Option<u32>,
offset: Option<u32>,
) -> impl Stream<Item = MonoEvent> + Send + 'static
pub async fn search( &self, query: String, kind: Option<SearchKind>, limit: Option<u32>, offset: Option<u32>, ) -> impl Stream<Item = MonoEvent> + Send + 'static
Search for tracks, albums, or artists
Sourcepub async fn lyrics(
&self,
id: u64,
) -> impl Stream<Item = MonoEvent> + Send + 'static
pub async fn lyrics( &self, id: u64, ) -> impl Stream<Item = MonoEvent> + Send + 'static
Get synchronized lyrics for a track by Tidal track ID
Sourcepub async fn recommendations(
&self,
id: u64,
) -> impl Stream<Item = MonoEvent> + Send + 'static
pub async fn recommendations( &self, id: u64, ) -> impl Stream<Item = MonoEvent> + Send + 'static
Get recommended tracks similar to a given track
Sourcepub async fn stream_url(
&self,
id: u64,
quality: Option<String>,
) -> impl Stream<Item = MonoEvent> + Send + 'static
pub async fn stream_url( &self, id: u64, quality: Option<String>, ) -> impl Stream<Item = MonoEvent> + Send + 'static
Resolve the direct CDN stream URL for a track